@@ -3,7 +3,6 @@ The default group of operations that pyflexebs has
 """
 import logging
 import time
-from pprint import pprint
 
 import boto3
 import ec2_metadata
@@ -49,7 +48,7 @@ def daemon() -> None:
     """
     metadata = ec2_metadata.ec2_metadata
     instance_id = metadata.instance_id
-    ec2 = boto3.resource('ec2')
+    ec2 = boto3.resource('ec2', region_name=metadata.region)
     instance = ec2.Instance(instance_id)
     volumes = instance.volumes.all()
 
@@ -108,4 +107,11 @@ def print_volumes() -> None:
     print("instance is [{}]".format(instance_id))
     volumes = instance.volumes.all()
     for v in volumes:
-        pprint(vars(v))
+        dump(v)
+
+
+def dump(obj):
+    for attr in dir(obj):
+        if attr.startswith("__"):
+            continue
+        print("obj.%s = %r" % (attr, getattr(obj, attr)))
